#include <libwccl/parser/Parser.h>

/**
 * @desc Parser constructor. Default tagset is NULL
 */
Parser::Parser(const Corpus2::Tagset& t) : tagset(t)
{
}

/**
 *
 */
Parser::~Parser()
{
	//
}

// ----------------------------------------------------------------------------

/**
 * @desc Overloaded parsing operator writed in string. Calls base method
 * @arg str operator as string
 * @return call method @see parserOperator(const std::istream&)
 */
/*
std::string Parser::parseOperator(const std::string& str) const
{
	std::stringstream ss (std::stringstream::in | std::stringstream::out);
	ss << str;

	return this->parseOperator(ss);
}
*/
/**
 * @desc Base method for parsing operator in stream
 * @arg istr input stream with operator
 * @return Operator
 */
/*
std::string Parser::parseOperator(std::istream& istr) const
{
	ANTLRLexer lexer(istr);
	ANTLRParser parser(lexer);

	return "Ala ma kota";
}
*/

// -----------------------------------------------------------------------------

/**
 * @desc Overloaded parsing expression writed in string. Calls base method
 * @arg str variables in string
 */
void Parser::parseExpression(const std::string& str) const
{
	std::stringstream ss (std::stringstream::in | std::stringstream::out);
	ss << str;

	return this->parseExpression(ss);
}

/**
 * @desc Base method for parsing expression in stream
 * @arg istr input stream with variable
 * @return Operator
 */
void Parser::parseExpression(std::istream& istr) const
{
	ANTLRLexer lexer(istr);
	ANTLRParser parser(lexer);

	try {
		parser.start_rules();

		std::cerr << "Syntax ok!" << std::endl;
	}
	catch (ParserException e) {
		std::cerr << e.info() << std::endl;
	}
	catch (...) {
		std::cerr << "Syntax error!" << std::endl;
	}
}
